@@ -40,8 +40,8 @@ def _f_expl_3_bogacki_shampine_adptv(x0, Y0, dx, *args, dYdx=None, econ=0.005832
 
     Returns
     -------
-    Y1 : Field or False
-        New value of Y
+    dY : Field
+        Delta of variable to be integrated
         False if step size too large
 
     Butcher tableau
@@ -68,9 +68,9 @@ def _f_expl_3_bogacki_shampine_adptv(x0, Y0, dx, *args, dYdx=None, econ=0.005832
     # Integration successful
     if emax <= 1.:
         # Suggest new stepsize
-        dxnew = safety*dx*emax**pgrow if econ > emax else 5.*dx
+        dxnew = safety*dx*emax**pgrow if econ < emax else 5.*dx
         x0.suggest(dxnew)
-        return Y0 + dx*(b0*k0 + b1*k1 + b2*k2)
+        return dx*(b0*k0 + b1*k1 + b2*k2)
     else:
         # Suggest new stepsize
         dxnew = np.maximum(safety*dx*emax**pshrink, 0.1*dx)
