@@ -25,8 +25,8 @@ def _f_expl_3_kutta(x0, Y0, dx, *args, dYdx=None, **kwargs):
 
     Returns
     -------
-    Y1 : Field
-        New value of Y
+    dY : Field
+        Delta of variable to be integrated
 
     Butcher tableau
     ---------------
@@ -40,7 +40,7 @@ def _f_expl_3_kutta(x0, Y0, dx, *args, dYdx=None, **kwargs):
     k1 = Y0.derivative(x0 + c1*dx, Y0 + a10*k0 * dx)
     k2 = Y0.derivative(x0 + dx, Y0 + (-k0 + a21*k1)*dx)
 
-    return Y0 + dx*(b0*k0 + b1*k1 + b2*k2)
+    return dx*(b0*k0 + b1*k1 + b2*k2)
 
 
 expl_3_kutta = Scheme(
