@@ -4,7 +4,7 @@ import numpy as np
 from scipy.sparse import linalg
 
 
-def _f_impl_1_euler_gmres(x0, Y0, dx, gmres_opt={}, *args, **kwargs):
+def _f_impl_1_euler_gmres(x0, Y0, dx, jac=None, gmres_opt={}, *args, **kwargs):
     """Implicit 1st-order Euler integration scheme with GMRES solver
 
     Parameters
@@ -15,6 +15,8 @@ def _f_impl_1_euler_gmres(x0, Y0, dx, gmres_opt={}, *args, **kwargs):
         Variable to be integrated at the beginning of scheme
     dx : IntVar
         Stepsize of integration variable
+    jac : Field, optional, defaul : None
+        Current Jacobian. Will be calculated, if not set
     gmres_opt : dict, optional, default : {}
         dictionary with options for scipy GMRES solver
     args : additional positional arguments
@@ -31,7 +33,8 @@ def _f_impl_1_euler_gmres(x0, Y0, dx, gmres_opt={}, *args, **kwargs):
     ---|---
        | 1 
     """
-    jac = Y0.jacobian(x0 + dx)
+    if jac is None:
+        jac = Y0.jacobian(x0 + dx)
     N = jac.shape[0]
     eye = np.eye(N)
     A = eye - dx*jac
@@ -39,7 +42,7 @@ def _f_impl_1_euler_gmres(x0, Y0, dx, gmres_opt={}, *args, **kwargs):
     if state != 0:
         return False
     else:
-        return res
+        return res - Y0
 
 
 impl_1_euler_gmres = Scheme(
